% call inverter model
inverter

% simulate with stochastic solver
state_mi = Mobj.species(2);
state_pi = Mobj.species(3);
state_pipi = Mobj.species(4);
state_do = Mobj.species(5);
state_pipido = Mobj.species(6);
state_degraded_mi = Mobj.species(7);
state_degraded_pi = Mobj.species(8);
state_degraded_pipi = Mobj.species(9);
state_pign = Mobj.species(11);
state_pipign = Mobj.species(12);
% choose which species to track
StatesToLog = [state_mi,state_degraded_mi];
cs = getconfigset(Mobj);
set(cs, 'SolverType', 'ssa');
set(cs.RuntimeOptions, 'StatesToLog', StatesToLog);
cs.SolverOptions.LogDecimation = 1;
timetorun = 60;
cs.StopTime = timetorun;

% the magic black box that all our numbers go into
[t_ssa, x_ssa] = sbiosimulate(Mobj, cs);

mi_gross = [1:1:length(x_ssa)-1];
for index=1:length(x_ssa)
    mi_gross(index) = x_ssa(index,1) + x_ssa(index,2);
end

% smooth it out
stepsize = 0.25;
slices = [0:stepsize:timetorun];
smooth_net = interp1(t_ssa,x_ssa(:,1),slices,'linear');
smooth_gross = interp1(t_ssa,mi_gross,slices,'linear');

% interpolate derivatives
dnet_dt = [0:1:length(slices)-1];
dgross_dt = [0:1:length(slices)-1];
for index=2:length(slices),
    dnet_dt(index) = (smooth_net(index)-smooth_net(index-1))/(stepsize);
    dgross_dt(index) = (smooth_gross(index)-smooth_gross(index-1))/(stepsize);
end

% repressor stats
nts = 238; % assuming lambda repressor, nucleotides/transcript
% convert to AA/sec
net_nts_rate = dnet_dt*nts;
gross_nts_rate = dgross_dt*nts;

set(gcf, 'color', 'white');
figure(1);
plot(slices,net_nts_rate,'r:')
hold on
plot(slices,gross_nts_rate,'g')
title('Load');
xlabel('Time (seconds)');
ylabel('Nucleotides per second');
text(timetorun/4,max(net_nts_rate)*.9,num2str(max(net_nts_rate)))
text(timetorun/4,max(net_nts_rate)*.95,'Max net nts/second')
text(2*timetorun/3,max(gross_nts_rate)*.9,num2str(max(gross_nts_rate)))
text(2*timetorun/3,max(gross_nts_rate)*.95,'Max gross nts/second')