% call inverter model
inverter

% simulate with stochastic solver
state_mi = Mobj.species(2);
state_pi = Mobj.species(3);
state_pipi = Mobj.species(4);
state_do = Mobj.species(5);
state_pipido = Mobj.species(6);
state_degraded_pi = Mobj.species(7);
state_degraded_pipi = Mobj.species(8);
state_pign = Mobj.species(10);
state_pipign = Mobj.species(11);
% choose which species to track
StatesToLog = [state_pi, state_pipi, state_pipido, state_degraded_pi, state_degraded_pipi, state_pign, state_pipign]; 
cs = getconfigset(Mobj);
set(cs, 'SolverType', 'ssa');
set(cs.RuntimeOptions, 'StatesToLog', StatesToLog);
cs.SolverOptions.LogDecimation = 1;
timetorun = 30;
cs.StopTime = timetorun;

% the magic black box that all our numbers go into
[t_ssa, x_ssa] = sbiosimulate(Mobj, cs);

% convert to "net" and "gross"
piT_net = [0:1:length(x_ssa)-1];
piT_gross = [0:1:length(x_ssa)-1];

pi = x_ssa(:,1);
pipi = x_ssa(:,2);
pipido = x_ssa(:,3);
pign = x_ssa(:,6);
pipign = x_ssa(:,7);

for index=1:length(x_ssa),
    piT_net(index) = x_ssa(index,1) + 2*(x_ssa(index,2) + x_ssa(index,3)) + x_ssa(index,6) + 2*x_ssa(index,7);
    piT_gross(index) = x_ssa(index,1) + 2*x_ssa(index,2) + 2*x_ssa(index,3) + x_ssa(index,4) + 2*x_ssa(index,5) + x_ssa(index,6) + 2*x_ssa(index,7);
end

% smooth it out
stepsize = 0.5;
slices = [0:stepsize:timetorun];
smooth_net = interp1(t_ssa,piT_net,slices,'linear');
smooth_gross = interp1(t_ssa,piT_gross,slices,'linear');

% interpolate derivatives
dnet_dt = [0:1:length(slices)-1];
dgross_dt = [0:1:length(slices)-1];
for index=2:length(slices),
    dnet_dt(index) = (smooth_net(index) - smooth_net(index-1)) /(stepsize);
    dgross_dt(index)=(smooth_gross(index)-smooth_gross(index-1))/(stepsize);
end

% length of repressor
aa = 238; % assuming lambda repressor, aa/protein
% convert to AA/sec
aa_rate = dgross_dt*aa;

set(gcf, 'color', 'white');
figure(1);
%plot(t_ssa,piT_net,'b');
%plot(slices,dnet_dt,'b:')
hold on
%plot(slices,aa_rate,'g')
%plot(t_ssa,dnet_dt,'b:');
plot(slices,smooth_net,'c')
hold on
%plot(t_ssa,piT_gross,'g');
hold on
%plot(slices,dgross_dt,'r');
hold on
%plot(slices,smooth_gross,'g:')
title('Load');
xlabel('Time (seconds)');
ylabel('Amino acids per second');
%text(timetorun/4,max(aa_rate)*.9,num2str(max(aa_rate)))
%text(timetorun/4,max(aa_rate)*.95,'Max AA/second')